<?php
/**
 * Listeners
 *
 * @package GamiPress\Paid_Memberships_Pro\Listeners
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Purchase membership listener
 *
 * @since 1.0.0
 *
 * @param MemberOrder $morder
 */
function gamipress_pmpro_purchase_membership( $morder ) {

    $user_id = $morder->user_id;
    $membership_id = $morder->membership_id;

    // Trigger purchase any membership
    do_action( 'gamipress_pmpro_purchase_membership', $membership_id, $user_id );

    // Trigger purchase specific membership
    do_action( 'gamipress_pmpro_purchase_specific_membership', $membership_id, $user_id );

}
add_action( 'pmpro_subscription_payment_completed', 'gamipress_pmpro_purchase_membership' );

/**
 * Purchase membership listener
 *
 * @since 1.0.0
 *
 * @param MemberOrder $morder
 */
function gamipress_pmpro_cancel_membership( $morder ) {

    $user_id = $morder->user_id;
    $membership_id = $morder->membership_id;

    // Trigger cancel any membership
    do_action( 'gamipress_pmpro_cancel_membership', $membership_id, $user_id );

    // Trigger cancel specific membership
    do_action( 'gamipress_pmpro_cancel_specific_membership', $membership_id, $user_id );

}
add_action( 'pmpro_subscription_cancelled', 'gamipress_pmpro_cancel_membership' );

/**
 * Purchase membership listener
 *
 * @since 1.0.0
 *
 * @param MemberOrder $morder
 */
function gamipress_pmpro_membership_expired( $morder ) {

    $user_id = $morder->user_id;
    $membership_id = $morder->membership_id;

    // Trigger any membership expired
    do_action( 'gamipress_pmpro_membership_expired', $membership_id, $user_id );

    // Trigger specific membership expired
    do_action( 'gamipress_pmpro_specific_membership_expired', $membership_id, $user_id );

}
add_action( 'pmpro_subscription_expired', 'gamipress_pmpro_membership_expired' );